==> aws-java-sdk-iot-1.11.29-sources.jar: com/amazonaws/services/iot/model/ListCertificatesByCAResult.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.iot.model;

import java.io.Serializable;

/**
 * <p>
 * The output of the ListCertificatesByCA operation.
 * </p>
 */
public class ListCertificatesByCAResult implements Serializable, Cloneable {

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     */
    private java.util.List<Certificate> certificates;
    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     */
    private String nextMarker;

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * 
     * @return The device certificates signed by the specified CA certificate.
     */

    public java.util.List<Certificate> getCertificates() {
        return certificates;
    }

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * 
     * @param certificates
     *        The device certificates signed by the specified CA certificate.
     */

    public void setCertificates(java.util.Collection<Certificate> certificates) {
        if (certificates == null) {
            this.certificates = null;
            return;
        }

        this.certificates = new java.util.ArrayList<Certificate>(certificates);
    }

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setCertificates(java.util.Collection)} or
     * {@link #withCertificates(java.util.Collection)} if you want to override
     * the existing values.
     * </p>
     * 
     * @param certificates
     *        The device certificates signed by the specified CA certificate.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListCertificatesByCAResult withCertificates(
            Certificate... certificates) {
        if (this.certificates == null) {
            setCertificates(new java.util.ArrayList<Certificate>(
                    certificates.length));
        }
        for (Certificate ele : certificates) {
            this.certificates.add(ele);
        }
        return this;
    }

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * 
     * @param certificates
     *        The device certificates signed by the specified CA certificate.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListCertificatesByCAResult withCertificates(
            java.util.Collection<Certificate> certificates) {
        setCertificates(certificates);
        return this;
    }

    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     * 
     * @param nextMarker
     *        The marker for the next set of results, or null if there are no
     *        additional results.
     */

    public void setNextMarker(String nextMarker) {
        this.nextMarker = nextMarker;
    }

    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     * 
     * @return The marker for the next set of results, or null if there are no
     *         additional results.
     */

    public String getNextMarker() {
        return this.nextMarker;
    }

    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     * 
     * @param nextMarker
     *        The marker for the next set of results, or null if there are no
     *        additional results.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListCertificatesByCAResult withNextMarker(String nextMarker) {
        setNextMarker(nextMarker);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getCertificates() != null)
            sb.append("Certificates: " + getCertificates() + ",");
        if (getNextMarker() != null)
            sb.append("NextMarker: " + getNextMarker());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof ListCertificatesByCAResult == false)
            return false;
        ListCertificatesByCAResult other = (ListCertificatesByCAResult) obj;
        if (other.getCertificates() == null ^ this.getCertificates() == null)
            return false;
        if (other.getCertificates() != null
                && other.getCertificates().equals(this.getCertificates()) == false)
            return false;
        if (other.getNextMarker() == null ^ this.getNextMarker() == null)
            return false;
        if (other.getNextMarker() != null
                && other.getNextMarker().equals(this.getNextMarker()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getCertificates() == null) ? 0 : getCertificates()
                        .hashCode());
        hashCode = prime * hashCode
                + ((getNextMarker() == null) ? 0 : getNextMarker().hashCode());
        return hashCode;
    }

    @Override
    public ListCertificatesByCAResult clone() {
        try {
            return (ListCertificatesByCAResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}

==> aws-java-sdk-iot-1.11.33-sources.jar: com/amazonaws/services/iot/model/ListCertificatesByCAResult.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.iot.model;

import java.io.Serializable;

/**
 * <p>
 * The output of the ListCertificatesByCA operation.
 * </p>
 */
public class ListCertificatesByCAResult extends
        com.amazonaws.AmazonWebServiceResult<com.amazonaws.ResponseMetadata>
        implements Serializable, Cloneable {

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     */
    private java.util.List<Certificate> certificates;
    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     */
    private String nextMarker;

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * 
     * @return The device certificates signed by the specified CA certificate.
     */

    public java.util.List<Certificate> getCertificates() {
        return certificates;
    }

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * 
     * @param certificates
     *        The device certificates signed by the specified CA certificate.
     */

    public void setCertificates(java.util.Collection<Certificate> certificates) {
        if (certificates == null) {
            this.certificates = null;
            return;
        }

        this.certificates = new java.util.ArrayList<Certificate>(certificates);
    }

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setCertificates(java.util.Collection)} or
     * {@link #withCertificates(java.util.Collection)} if you want to override
     * the existing values.
     * </p>
     * 
     * @param certificates
     *        The device certificates signed by the specified CA certificate.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListCertificatesByCAResult withCertificates(
            Certificate... certificates) {
        if (this.certificates == null) {
            setCertificates(new java.util.ArrayList<Certificate>(
                    certificates.length));
        }
        for (Certificate ele : certificates) {
            this.certificates.add(ele);
        }
        return this;
    }

    /**
     * <p>
     * The device certificates signed by the specified CA certificate.
     * </p>
     * 
     * @param certificates
     *        The device certificates signed by the specified CA certificate.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListCertificatesByCAResult withCertificates(
            java.util.Collection<Certificate> certificates) {
        setCertificates(certificates);
        return this;
    }

    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     * 
     * @param nextMarker
     *        The marker for the next set of results, or null if there are no
     *        additional results.
     */

    public void setNextMarker(String nextMarker) {
        this.nextMarker = nextMarker;
    }

    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     * 
     * @return The marker for the next set of results, or null if there are no
     *         additional results.
     */

    public String getNextMarker() {
        return this.nextMarker;
    }

    /**
     * <p>
     * The marker for the next set of results, or null if there are no
     * additional results.
     * </p>
     * 
     * @param nextMarker
     *        The marker for the next set of results, or null if there are no
     *        additional results.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListCertificatesByCAResult withNextMarker(String nextMarker) {
        setNextMarker(nextMarker);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getCertificates() != null)
            sb.append("Certificates: " + getCertificates() + ",");
        if (getNextMarker() != null)
            sb.append("NextMarker: " + getNextMarker());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof ListCertificatesByCAResult == false)
            return false;
        ListCertificatesByCAResult other = (ListCertificatesByCAResult) obj;
        if (other.getCertificates() == null ^ this.getCertificates() == null)
            return false;
        if (other.getCertificates() != null
                && other.getCertificates().equals(this.getCertificates()) == false)
            return false;
        if (other.getNextMarker() == null ^ this.getNextMarker() == null)
            return false;
        if (other.getNextMarker() != null
                && other.getNextMarker().equals(this.getNextMarker()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getCertificates() == null) ? 0 : getCertificates()
                        .hashCode());
        hashCode = prime * hashCode
                + ((getNextMarker() == null) ? 0 : getNextMarker().hashCode());
        return hashCode;
    }

    @Override
    public ListCertificatesByCAResult clone() {
        try {
            return (ListCertificatesByCAResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
